@@ -103,7 +103,10 @@ class DbtService:
 
         # Copy source definitions if they exist
         self._copy_sources_to_temp_project(temp_dir)
-        
+
+        # Copy profile-specific macros if they exist
+        self._copy_macros_to_temp_project(temp_dir)
+
         # Add macro to prevent dbt from adding LIMIT clauses
         self._add_no_limit_macro(temp_dir)
 
@@ -157,6 +160,45 @@ class DbtService:
             if os.environ.get('SQLBOT_DEBUG'):
                 print(f"🔍 DEBUG: Could not copy schema file: {e}")
 
+    def _copy_macros_to_temp_project(self, temp_dir: Path) -> None:
+        """
+        Copy profile-specific macros to the temporary dbt project.
+
+        Args:
+            temp_dir: Path to the temporary dbt project directory
+        """
+        import shutil
+        from ..llm_integration import get_profile_paths
+
+        try:
+            profile_name = self.config.profile
+            _, macro_paths = get_profile_paths(profile_name)
+
+            # Find the first existing macros directory
+            source_macros_dir = None
+            for path in macro_paths:
+                if os.path.exists(path) and os.path.isdir(path):
+                    source_macros_dir = path
+                    break
+
+            if source_macros_dir:
+                # Create macros directory in temp project
+                macros_dir = temp_dir / 'macros'
+                macros_dir.mkdir(exist_ok=True)
+
+                # Copy all .sql macro files
+                for macro_file in Path(source_macros_dir).glob('*.sql'):
+                    dest_file = macros_dir / macro_file.name
+                    shutil.copy2(macro_file, dest_file)
+
+                    if os.environ.get('SQLBOT_DEBUG'):
+                        print(f"🔍 DEBUG: Copied macro file from {macro_file} to {dest_file}")
+
+        except Exception as e:
+            # Don't fail if macro copying fails - just log it
+            if os.environ.get('SQLBOT_DEBUG'):
+                print(f"🔍 DEBUG: Could not copy macro files: {e}")
+
     def _add_no_limit_macro(self, temp_dir: Path) -> None:
         """
         Add macro to prevent dbt from adding LIMIT clauses to queries.
@@ -248,7 +290,9 @@ class DbtService:
                 "dbt", "show",
                 "--inline", clean_query,
                 "--profile", self.config.profile,
-                "--log-level", "warn"  # Reduce noise
+                "--log-level", "warn",  # Reduce noise
+                "--output", "json",  # Get JSON output instead of formatted table to avoid truncation
+                "--printer-width", "10000"  # Set very large width to prevent column truncation
             ]
 
             # Don't add --limit flag since we use macro to prevent dbt from adding LIMIT
@@ -272,29 +316,28 @@ class DbtService:
             execution_time = time.time() - start_time
 
             if result.returncode == 0:
-                # Parse dbt show table output
-                try:
-                    output = result.stdout.strip()
-                    data, columns = self._parse_dbt_table_output(output)
+                # Parse dbt show JSON output
+                output = result.stdout.strip()
+                data, columns, parse_success = self._parse_dbt_json_output(output)
 
+                # Check if parsing failed (distinct from valid query returning 0 rows)
+                if not parse_success:
+                    # JSON parsing failed - return error with debug info
                     return QueryResult(
-                        success=True,
+                        success=False,
                         query_type=QueryType.SQL,
                         execution_time=execution_time,
-                        data=data,
-                        columns=columns,
-                        row_count=len(data)
-                    )
-                except Exception as parse_error:
-                    # Fallback to raw output if parsing fails
-                    return QueryResult(
-                        success=True,
-                        query_type=QueryType.SQL,
-                        execution_time=execution_time,
-                        data=[{"raw_output": result.stdout.strip()}],
-                        columns=["raw_output"],
-                        row_count=1
+                        error=f"Failed to parse dbt show output. Output preview: {output[:500]}"
                     )
+
+                return QueryResult(
+                    success=True,
+                    query_type=QueryType.SQL,
+                    execution_time=execution_time,
+                    data=data,
+                    columns=columns,
+                    row_count=len(data)
+                )
             else:
                 # Command failed
                 error_msg = result.stderr.strip() or result.stdout.strip() or "Unknown error"
@@ -313,7 +356,41 @@ class DbtService:
                 execution_time=execution_time,
                 error=f"Query execution failed: {str(e)}"
             )
-    
+
+    def _parse_dbt_json_output(self, output: str):
+        """Parse dbt show JSON output into structured data.
+
+        Returns:
+            Tuple of (data, columns, parse_success) where:
+            - data: List of row dicts (empty list if no rows)
+            - columns: List of column names (empty list if no rows)
+            - parse_success: True if JSON was valid and had 'show' key, False if parsing failed
+        """
+        import json
+
+        try:
+            # dbt show --output json returns JSON with "show" key containing array of row objects
+            obj = json.loads(output)
+
+            if 'show' in obj and isinstance(obj['show'], list):
+                rows = obj['show']
+
+                if not rows:
+                    # Valid query that returned 0 rows - this is a successful parse
+                    return [], [], True
+
+                # Extract columns from first row's keys
+                columns = list(rows[0].keys())
+
+                # Data is already in dict format
+                return rows, columns, True
+
+        except json.JSONDecodeError as e:
+            # JSON parsing failed
+            pass
+
+        # If we didn't find valid show data, return empty with parse_success=False
+        return [], [], False
 
     def _parse_dbt_table_output(self, output: str):
         """Parse dbt show table output into structured data."""
