@@ -25,6 +25,12 @@ from sqlbot.interfaces.theme_system import get_theme_manager, ThemeMode
 # Load environment variables using dotenv as fallback (dotyaml will override these)
 load_dotenv()
 
+# Import utilities
+from sqlbot.utils import debug_log, get_sqlbot_dir
+
+# Ensure .sqlbot directory exists for logs and other data
+_sqlbot_dir = get_sqlbot_dir()
+
 # Initialize configuration system early to load YAML config and set environment variables
 # This ensures OPENAI_API_KEY and other config values are available before LLM initialization
 # Skip this during tests to avoid overriding test environment variables
@@ -114,7 +120,7 @@ try:
 except ImportError:
     try:
         # Fallback to absolute import (when run as script)
-        from llm_integration import handle_llm_query
+        from sqlbot.llm_integration import handle_llm_query
         LLM_AVAILABLE = True
         pass  # LLM integration loaded - will show message later
     except ImportError as e:
@@ -876,8 +882,13 @@ def is_sql_query(query):
     """Detect if query should be treated as SQL/dbt (ends with semicolon)"""
     return query.strip().endswith(';')
 
-def show_banner(is_no_repl=False, profile=None, llm_model=None, llm_available=False):
-    """Show SQLBot banner with setup information"""
+def show_banner(is_no_repl=False, profile=None, llm_model=None, llm_available=False, unified_display=None):
+    """
+    Show SQLBot banner with setup information.
+
+    If unified_display is provided, adds banner as a system message to the chat.
+    Otherwise, prints to console for backwards compatibility.
+    """
     from sqlbot.interfaces.banner import get_banner_content, get_interactive_banner_content
     from rich.markdown import Markdown
     from rich.panel import Panel
@@ -889,9 +900,10 @@ def show_banner(is_no_repl=False, profile=None, llm_model=None, llm_available=Fa
         from sqlbot.core.config import SQLBotConfig
         config = SQLBotConfig.from_env(profile=profile)
         # Initialize READONLY_MODE based on config (unless overridden by CLI)
-        global READONLY_MODE
+        global READONLY_MODE, READONLY_CLI_MODE
         if not READONLY_CLI_MODE:  # Only if not explicitly set by --dangerous flag
             READONLY_MODE = not config.dangerous  # dangerous=false means safeguards enabled
+            debug_log(f"show_banner(): Reset READONLY_MODE={READONLY_MODE} from config (READONLY_CLI_MODE={READONLY_CLI_MODE})")
         dbt_service = get_dbt_service(config)
         dbt_config_info = dbt_service.get_dbt_config_info()
     except Exception:
@@ -923,56 +935,91 @@ def show_banner(is_no_repl=False, profile=None, llm_model=None, llm_available=Fa
             dbt_config_info=dbt_config_info
         )
 
-        # Use Rich Markdown for proper formatting
-        theme = get_theme_manager()
-        markdown_content = Markdown(banner_text)
+        # If unified_display is provided, add as system message to chat
+        if unified_display:
+            unified_display.add_system_message(banner_text)
+        else:
+            # Fallback: Use Rich Markdown for proper formatting
+            theme = get_theme_manager()
+            markdown_content = Markdown(banner_text)
 
-        # Display in a panel with theme colors
-        ai_color = theme.get_color('ai_response')
-        rich_console.print(Panel(markdown_content, border_style=ai_color))
+            # Display in a panel with theme colors
+            ai_color = theme.get_color('ai_response')
+            rich_console.print(Panel(markdown_content, border_style=ai_color))
 
 
 
 def main():
     """Main entry point for SQLBot."""
     import sys
-    
+
     # Global variable declarations
     global PREVIEW_MODE, READONLY_MODE, READONLY_CLI_MODE, SHOW_HISTORY, SHOW_FULL_HISTORY
-    
+
+    # DEBUG: Log at start
+    debug_log(f"\n=== MAIN() START ===")
+    debug_log(f"Initial: READONLY_MODE={READONLY_MODE}, READONLY_CLI_MODE={READONLY_CLI_MODE}")
+
     # Parse arguments with subcommand support
     from .cli import parse_args_with_subcommands, handle_cli_subcommands
-    
+
+    debug_log(f"About to parse args...")
+
     args = parse_args_with_subcommands()
+
+    debug_log(f"Args parsed: args is None = {args is None}")
+
     if args is None:
+        debug_log(f"Returning early - args is None")
         return  # Help was shown
     
     # Handle subcommands first
+    debug_log(f"Checking subcommands: args.command = {args.command}")
+
     if args.command:
         exit_code = handle_cli_subcommands(args)
         sys.exit(exit_code)
-    
+
+    # Handle web mode
+    debug_log(f"Checking web mode: args.web = {getattr(args, 'web', False)}")
+
+    if hasattr(args, 'web') and args.web:
+        from .webapp import run_webapp
+        # Pass dangerous flag to webapp
+        dangerous_mode = getattr(args, 'dangerous', False)
+        run_webapp(dangerous=dangerous_mode)
+        return
+
     # Apply theme early based on command line argument
+    debug_log(f"Setting theme: args.theme = {args.theme}")
+
     theme_map = {mode.value: mode for mode in ThemeMode}
     theme_manager = get_theme_manager()
     theme_manager.set_theme(theme_map[args.theme])
-    
+
+    debug_log(f"Theme set successfully")
+
     # Theme is now set - all subsequent UI should use theme colors
-    
+
     # Global variable declarations
     global dbt, LLM_AVAILABLE
-    
+
     # Show banner first ONLY for CLI mode with query (not for Textual app)
     # Banner logic: Don't show banner when query is provided from command line
     # Banner will be shown later in interactive mode startup if appropriate
     
     # Initialize everything after banner display
+    debug_log(f"About to initialize dbt...")
+
     if dbt is None:
         from dbt.cli.main import dbtRunner
         dbt = dbtRunner()
-    
+
+    debug_log(f"dbt initialized")
+
     # Handle conversation continuation
     if hasattr(args, 'continue_session') and args.continue_session:
+        debug_log(f"Handling continue_session...")
         # Load previous conversation instead of clearing
         try:
             from .conversation_persistence import load_conversation_history
@@ -1140,26 +1187,32 @@ def main():
             except ImportError:
                 # If we can't import the module, just skip setting the flag
                 pass
-    
+
+    # Set global mode flags BEFORE checking for query (applies to both interactive and non-interactive modes)
+    debug_log(f"REACHED FLAG-SETTING CODE!")
+    debug_log(f"main(): About to check flags: args.dangerous={getattr(args, 'dangerous', 'NOT FOUND')}, args.preview={getattr(args, 'preview', 'NOT FOUND')}")
+
+    if args.preview:
+        PREVIEW_MODE = True
+
+    if hasattr(args, 'dangerous') and args.dangerous:
+        READONLY_MODE = False
+        READONLY_CLI_MODE = True  # CLI mode - safeguards explicitly disabled
+        debug_log(f"main(): Set READONLY_MODE={READONLY_MODE}, READONLY_CLI_MODE={READONLY_CLI_MODE}")
+    else:
+        debug_log(f"main(): NOT setting dangerous mode: hasattr={hasattr(args, 'dangerous')}, value={getattr(args, 'dangerous', None)}")
+
+    if args.history:
+        SHOW_HISTORY = True
+
+    if args.full_history:
+        SHOW_HISTORY = True  # Enable history display
+        SHOW_FULL_HISTORY = True  # Enable full history mode
+
     # Check for command line input
     if args.query:
         # Join all query arguments as a single query
         query = ' '.join(args.query)
-
-        # Set global mode flags (but don't print messages yet - banner must come first)
-        if args.preview:
-            PREVIEW_MODE = True
-
-        if args.dangerous:
-            READONLY_MODE = False
-            READONLY_CLI_MODE = True  # CLI mode - safeguards explicitly disabled
-        
-        if args.history:
-            SHOW_HISTORY = True
-        
-        if args.full_history:
-            SHOW_HISTORY = True  # Enable history display
-            SHOW_FULL_HISTORY = True  # Enable full history mode
         
         # Execute query using appropriate interface
         if args.textual and LLM_AVAILABLE:
@@ -1171,11 +1224,9 @@ def main():
             return
         else:
             # Default: text-based CLI mode
-            # Show banner when NOT in --no-repl mode
-            if not args.no_repl:
-                show_banner(is_no_repl=False, profile=args.profile, llm_model=llm_model, llm_available=LLM_AVAILABLE)
-            else:
-                # In --no-repl mode, just add spacing
+            # Banner will be shown by start_unified_repl for interactive mode
+            if args.no_repl:
+                # In --no-repl mode, just add spacing (no banner)
                 rich_console.print()
                 rich_console.print()
 
@@ -1193,7 +1244,7 @@ def main():
                 rich_console.print("\n[dim]Exiting (--no-repl mode)[/dim]")
                 return  # Exit after query execution
             else:
-                # Continue to interactive CLI mode
+                # Continue to interactive CLI mode (banner will be shown by start_unified_repl)
                 _start_cli_interactive_mode(rich_console)
                 return
 
@@ -1205,8 +1256,7 @@ def main():
             textual_repl = create_textual_repl_from_args(args)
             textual_repl.run()
         else:
-            # Default: text-based interactive REPL
-            show_banner(is_no_repl=False, profile=args.profile, llm_model=llm_model, llm_available=LLM_AVAILABLE)
+            # Default: text-based interactive REPL (banner will be shown by start_unified_repl)
             _start_cli_interactive_mode(rich_console)
 
 
@@ -1355,6 +1405,13 @@ def start_unified_repl(memory_manager, console):
     cli_display.set_interactive_mode(True)  # Enable prompt overwriting
     unified_display = UnifiedMessageDisplay(cli_display, memory_manager)
 
+    # Show banner as first system message in chat
+    global DBT_PROFILE_NAME, LLM_AVAILABLE
+    llm_model = None
+    if LLM_AVAILABLE:
+        llm_model = os.getenv('SQLBOT_LLM_MODEL', 'gpt-5')
+    show_banner(is_no_repl=False, profile=DBT_PROFILE_NAME, llm_model=llm_model, llm_available=LLM_AVAILABLE, unified_display=unified_display)
+
     # Create execute_llm_func with access to unified_display and conversation sync
     def execute_llm_func(q: str) -> str:
         global SHOW_HISTORY, SHOW_FULL_HISTORY
@@ -1435,6 +1492,9 @@ def start_unified_repl(memory_manager, console):
                             # If line ends with semicolon, submit immediately
                             if line.rstrip().endswith(';'):
                                 break
+                            # If line is a slash command or exit command, submit immediately
+                            if line.startswith('/') or line.lower() in ['exit', 'quit', 'q']:
+                                break
                             # Continue to allow multi-line, but user can press Enter on blank line to submit
                         else:
                             # Empty first line, return empty string
